@@ -1,6 +1,6 @@
 /***
 |''Name''|ImageMacroPlugin|
-|''Version''|0.9.0|
+|''Version''|0.9.2|
 |''Description''|Allows the rendering of svg images in a TiddlyWiki|
 |''Author''|Osmosoft|
 |''License''|[[BSD|http://www.opensource.org/licenses/bsd-license.php]]|
@@ -56,6 +56,12 @@ var macro = config.macros.image = {
 			var image = startupImages[i];
 			macro.renderImage(place, image.title, { idPrefix: "" });
 		}
+		var data = new Image();
+		data.onload = function() {
+			macro.supportsDataUris = this.width != 1 || this.height != 1 ? false : true;
+		};
+		data.onerror = data.onload;
+		data.src = "data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==";
 	},
 	refreshImage: function(src) {
 		var elements = macro._image_tag_cache[src] ? macro._image_tag_cache[src] : [];
@@ -82,7 +88,6 @@ var macro = config.macros.image = {
 	isBinaryImageTiddler: function(tiddler) {
 		return macro.isBinaryImageType(tiddler.fields['server.content-type']);
 	},
-	supportsDataUris: false,
 	renderImage: function(place, imageSource, options) {
 		var imageTiddler = store.getTiddler(imageSource);
 		var container;
@@ -156,6 +161,61 @@ var macro = config.macros.image = {
 			return macro._renderBinaryImageUrl(place, resourceURI, options);
 		}
 	},
+	_renderImageTag: function(container, src, width, height, options) {
+		var img;
+		img = $("<img />").appendTo(container);
+		if(height) {
+			img.attr("height", height);
+		}
+		if(width) {
+			img.attr("width", width);
+		}
+		if(macro.ieVersion && macro.ieVersion < 7 && macro.shim && options.ie6png) {
+			$(img).css({width: userW, height: userH,
+					filter: "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='%0', sizingMethod='scale')".format(src)
+				}).attr("src", macro.shim);
+		} else {
+			img.attr("src", src);
+		}
+		if(!macro._image_tag_cache[options.srcUrl]) {
+			macro._image_tag_cache[options.srcUrl] = [];
+		}
+		img = $(img).addClass(options.imageClass)[0];
+		macro._image_tag_cache[options.srcUrl].push(img);
+		return img;
+	},
+	_getDimensions: function(realDimensions, reqDimensions, preserve) {
+		var w = realDimensions.width;
+		var h = realDimensions.height;
+		var reqh = reqDimensions.height;
+		var reqw = reqDimensions.width;
+		var finalw = w, finalh = h;
+		var ratiow = reqw / w, ratioh = reqh / h;
+		var scaledw = ratioh * w;
+		var scaledh = ratiow * h;
+		if(!reqw && reqh) {
+			finalw = scaledw;
+			finalh = reqh;
+		} else if(reqw && !reqh) {
+			finalw = reqw;
+			finalh = scaledh;
+		} else if(reqh && reqw) {
+			var preserveWidth = w > h ? true : false;
+			if(preserve) {
+				if(preserveWidth && scaledh < reqh) {
+					finalh = scaledh;
+					finalw = reqw;
+				} else {
+					finalh = reqh;
+					finalw = scaledw;
+				}
+			} else {
+				finalw = reqw;
+				finalh = reqh;
+			}
+		}
+		return { width: parseInt(finalw, 10), height: parseInt(finalh, 10) };
+	},
 	_renderBinaryImageUrl: function(container, src, options) {
 		var srcUrl = options.src ? options.src : src;
 		srcUrl = srcUrl.indexOf("/") === -1 ? "/%0".format(srcUrl) : srcUrl; // for IE. 
@@ -172,43 +232,10 @@ var macro = config.macros.image = {
 					macro._renderAlternateText(container, options);
 				}
 			} else {
-				var preserve = options.preserveAspectRatio;
-				var w = dimensions.width;
-				var h = dimensions.height;
-				var userH = preserve && h < options.height ? h : options.height;
-				var userW = preserve && w < options.width ? w : options.width;
-				if(w && h) {
-					var preserveWidth = preserve && w > h;
-					var preserveHeight = preserve && h > w;
-					var ratio;
-					if(userH && !userW || preserveHeight) {
-						ratio = userH / h;
-						userW = parseInt(ratio * w, 10);
-					} else if (userW && !userH || preserveWidth) {
-						ratio = userW / w;
-						userH = parseInt(ratio * h, 10);
-					}
-					userW = userW ? userW : w;
-					userH = userH ? userH : h;
-				}
-				var img = $("<img />").addClass(options.imageClass).appendTo(container);
-				if(userH) {
-					img.attr("height", userH);
-				}
-				if(userW) {
-					img.attr("width", userW);
-				}
-				if(macro.ieVersion && macro.ieVersion < 7 && macro.shim) {
-					$(img).css({width: userW, height: userH,
-							filter: "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='%0', sizingMethod='scale')".format(src)
-						}).attr("src", macro.shim);
-				} else {
-					img.attr("src", src);
-				}
-				if(!macro._image_tag_cache[srcUrl]) {
-					macro._image_tag_cache[srcUrl] = [];
-				}
-				macro._image_tag_cache[srcUrl].push(img);
+				var dim = macro._getDimensions(dimensions, { 
+					width: options.width, height: options.height }, options.preserveAspectRatio);
+				options.srcUrl = srcUrl;
+				macro._renderImageTag(container, src, dim.width, dim.height, options);
 			}
 		};
 
@@ -345,34 +372,25 @@ var macro = config.macros.image = {
 	}
 };
 
-var datauriTest = function() {
-	var data = new Image();
-	data.onload = function() {
-		macro.supportsDataUris = this.width != 1 || this.height != 1 ? false : true;
-	};
-	data.onerror = data.onload;
-	data.src = "data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==";
-};
-datauriTest();
-
 // update views
 var _oldwikifiedview = config.macros.view.views.wikified;
 // update wikifier to check tiddler type before rendering
-config.macros.view.views.wikified = function(value, place, params, wikifier, paramString, tiddler) {
-	if(macro.isImageTiddler(tiddler) && params[0] == "text") {
-		var newplace = $("<div />").addClass("wikifiedImage").appendTo(place)[0];
-		macro.renderImage(newplace, tiddler.title, { alt: macro.locale.badImage });
-	} else {
-		_oldwikifiedview.apply(this, arguments);
+merge(config.macros.view.views, {
+	wikified: function(value, place, params, wikifier, paramString, tiddler) {
+		if(macro.isImageTiddler(tiddler) && params[0] == "text") {
+			var newplace = $("<div />").addClass("wikifiedImage").appendTo(place)[0];
+			macro.renderImage(newplace, tiddler.title, { alt: macro.locale.badImage });
+		} else {
+			_oldwikifiedview.apply(this, arguments);
+		}
+	},
+	image: function(value, place, params, wikifier, paramString, tiddler) {
+		// a field can point to another tiddler whereas text is the current tiddler.
+		var title = params[0] == "text" ? tiddler.title : value;
+		paramString = '"%0" %1'.format(title, params.splice(2).join(" "))
+		invokeMacro(place, "image", paramString, null, tiddler);
 	}
-};
-config.macros.view.views.image = function(value, place, params, wikifier, paramString, tiddler) {
-	// a field can point to another tiddler whereas text is the current tiddler.
-	var title = params[0] == "text" ? tiddler.title : value;
-	var paramString = '"%0" %1'.format(title, params.splice(2).join(" "))
-	invokeMacro(place, "image", paramString, null, tiddler);
-};
-
+});
 config.shadowTiddlers.StyleSheetImageMacro = [".wikifiedImage svg, .wikifiedImage .image { width: 80%; }",
 	".svgImageText { background-color:[[ColorPalette::Error]]; color:#ddd; display: inline-block; }",
 	"span.svgImageText { display: inline-block; overflow-hidden; }"
